==> kadu_1.2.orig.tar.bz2: kadu-1.2/plugins/autostatus/translations/autostatus_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <source>Autostatus file</source>
        <translation>Soubor s automatickým stavem</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Čas</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation><numerusform>%n sekunda</numerusform><numerusform>%n sekundy</numerusform><numerusform>%n sekund</numerusform></translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Připojený</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Zaneprázdněný</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Neviditelný</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Chování</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <source>AutoStatus</source>
        <translation>Automatický stav</translation>
    </message>
</context>
<context>
    <name>AutostatusActions</name>
    <message>
        <source>&amp;Autostatus</source>
        <translation>&amp;Automatický stav</translation>
    </message>
</context>
</TS>

==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/autostatus/translations/autostatus_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <source>Autostatus file</source>
        <translation>Soubor s automatickým stavem</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Čas</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation>
            <numerusform>%n sekunda</numerusform>
            <numerusform>%n sekundy</numerusform>
            <numerusform>%n sekund</numerusform>
        </translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Připojený</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Zaneprázdněný</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Neviditelný</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Chování</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <source>AutoStatus</source>
        <translation>Automatický stav</translation>
    </message>
</context>
<context>
    <name>AutostatusActions</name>
    <message>
        <source>&amp;Autostatus</source>
        <translation>&amp;Automatický stav</translation>
    </message>
</context>
</TS>
